#ifndef _ELM_MAPBUF_INTERNAL_PART_EO_H_
#define _ELM_MAPBUF_INTERNAL_PART_EO_H_

#ifndef _ELM_MAPBUF_INTERNAL_PART_EO_CLASS_TYPE
#define _ELM_MAPBUF_INTERNAL_PART_EO_CLASS_TYPE

typedef Eo Elm_Mapbuf_Internal_Part;

#endif

#ifndef _ELM_MAPBUF_INTERNAL_PART_EO_TYPES
#define _ELM_MAPBUF_INTERNAL_PART_EO_TYPES


#endif
/** Elementary mapbuf internal part class
 *
 * @ingroup Elm_Mapbuf_Internal_Part
 */
#define ELM_MAPBUF_INTERNAL_PART_CLASS elm_mapbuf_internal_part_class_get()

EWAPI const Efl_Class *elm_mapbuf_internal_part_class_get(void);

#endif
